#include "customcanvas.h"
#include <QtGui>

CustomCanvas::CustomCanvas(QWidget *parent)
: QWidget(parent)
{
    scribbling=false;
    setAttribute(Qt::WA_StaticContents);
    image=new QImage(this->width(),this->height(),QImage::Format_RGB32);
    image->fill(qRgb(255, 255, 255));
}

void CustomCanvas::mousePressEvent(QMouseEvent *event)
{
    if (event->button() == Qt::LeftButton) {
        lastPoint = event->pos();
        scribbling = true;
    }
}

void CustomCanvas::mouseMoveEvent(QMouseEvent *event)
{

    if (event->buttons() & Qt::LeftButton && scribbling)
    {
        QPainter painter(image);
        painter.setPen(QPen(Qt::black, 15, Qt::SolidLine, Qt::RoundCap,
                    Qt::RoundJoin));
        painter.drawLine(lastPoint, event->pos());
        lastPoint = event->pos();
        update();
    }
}

void CustomCanvas::mouseReleaseEvent(QMouseEvent *event)
{
    if (event->button() == Qt::LeftButton && scribbling) {
        update();
        scribbling = false;
    }
}

void CustomCanvas::paintEvent(QPaintEvent * /* event */)
{
    QPainter painter(this);
    painter.drawImage(QPoint(0, 0), *image);
}

void CustomCanvas::resizeEvent(QResizeEvent * event )
{
    QImage* newImage=new QImage(event->size(),QImage::Format_RGB32);
    newImage->fill(qRgb(255, 255, 255));
    QPainter painter(newImage);
    painter.drawImage(QPoint(0, 0), *image);
    image = newImage;
    update();
    QWidget::resizeEvent(event);
}
